
/**
 * Trieda slúži na definíciu rôznych vlastností miestnosti.
 */
public class Miestnosť
{
	// Zoznam dverí vedúcich z tejto miestnosti do ďalších (predvolene je
	// prázdny).
	private final GRobot.Zoznam<Miestnosť> dvere =
		new GRobot.Zoznam<Miestnosť>();

	// Zoznam predmetov, ktoré sú prítomné (viditeľné) v tejto miestnosti
	// (predvolene je prázdny).
	private final GRobot.Zoznam<Predmet> zoznamPredmetov =
		new GRobot.Zoznam<Predmet>();

	// Názov tejto miestnosti – jeho zadanie vyžaduje jediný konštruktor.
	private String názov;

	// Slovný opis miestnosti – jeho zadanie vyžaduje jediný konštruktor.
	private String opis;


	/**
	 * Konštruktor vyžaduje zadanie názvu a slovného opisu miestnosti.
	 */
	public Miestnosť(String názov, String opis)
	{
		priraďNázov(názov);
		priraďOpis(opis);
	}


	/**
	 * Vloženie predmetu do zoznamu.
	 */
	public void vložPredmet(Predmet predmet)
	{
		zoznamPredmetov.pridaj(predmet);
	}

	/**
	 * Odstránenie predmetu zo zoznamu.
	 */
	public void odstráňPredmet(Predmet predmet)
	{
		zoznamPredmetov.odober(predmet);
	}

	/**
	 * Nájdenie predmetu v zozname podľa názvu.
	 */
	public Predmet hľadajPredmet(String názovPredmetu)
	{
		// Hľadám predmet (pri hľadaní používam metódu porovnajNázov).
		// Keď ho nájdem, vrátim nájdenú inštanciu.
		for (Predmet predmet : zoznamPredmetov)
			if (predmet.porovnajNázov(názovPredmetu))
				return predmet;

		// Inak vrátim null.
		return null;
	}

	/**
	 * Zostavenie a výpis zoznamu predmetov, ktoré sú prítomné (viditeľné)
	 * v tejto miestnosti, na obrazovku.
	 */
	public void vypíšZoznamPredmetov()
	{
		if (zoznamPredmetov.veľkosť() <= 0) return;

		StringBuffer zoznam = new StringBuffer(
			"Vidíš tu nasledujúce predmety: " +
				zoznamPredmetov.daj(0).názov());

		for (int i = 1; i < zoznamPredmetov.veľkosť(); ++i)
			zoznam.append(", " + zoznamPredmetov.daj(i).názov());

		zoznam.append(".");
		Adventúra.vypíšText(zoznam);
	}


	/**
	 * Vytvorenie prepojenia s inou miestnosťou, to jest pridanie inštancie
	 * inej miestnosti do vnútorného zoznamu tejto miestnosti. Tie
	 * miestnosti, ktoré sú v zozname dverí, do tých jestvuje jednosmerný
	 * prechod, čiže hráč môže opustiť túto miestnosť a vstúpiť do hociktorej
	 * miestnosti v zozname dverí. (Z toho vyplýva, že v skutočnosti
	 * nejestvuje žiadna konkrétna trieda „Dvere“.) Na to, aby bol prechod
	 * obojsmerný, musí byť definované aj spätné prepojenie.
	 */
	public void prepojMaS(Miestnosť ináMiestnosť)
	{
		dvere.pridaj(ináMiestnosť);
	}

	/**
	 * Nájdenie miestnosti v zozname dverí podľa názvu.
	 */
	public Miestnosť hľadajDvere(String cieľováMiestnosť)
	{
		// Hľadám dvere (pri hľadaní používam metódu porovnajNázov).
		// Keď ich nájdem, vrátim nájdenú inštanciu.
		for (Miestnosť cieľ : dvere)
			if (cieľ.porovnajNázov(cieľováMiestnosť))
				return cieľ;

		// Inak vrátim null.
		return null;
	}

	/**
	 * Zostavenie a výpis zoznamu dverí na obrazovku.
	 */
	public void vypíšZoznamDverí()
	{
		if (dvere.veľkosť() <= 0) return;

		StringBuffer zoznam = new StringBuffer(
			"Môžeš ísť na tieto miesta: " + dvere.daj(0).názov());

		for (int i = 1; i < dvere.veľkosť(); ++i)
			zoznam.append(", " + dvere.daj(i).názov());

		zoznam.append(".");
		Adventúra.vypíšText(zoznam);
	}


	/**
	 * Priradenie nového názvu. Túto metódu používa konštruktor, ale môže
	 * poslúžiť aj na zmenu názvu miestnosti počas hry.
	 */
	public void priraďNázov(String novýNázov)
	{
		názov = novýNázov;
	}

	/**
	 * Metóda zistí, či sa názov tejto miestnosti zhoduje so zadaným
	 * reťazcom. To je využiteľné pri hľadaní konkrétnej miestnosti
	 * v zozname miestností.
	 */
	public boolean porovnajNázov(String názovNaPorovnanie)
	{
		return názov.equalsIgnoreCase(názovNaPorovnanie);
	}

	/**
	 * Metóda vráti názov tejto miestnosti.
	 */
	public String názov()
	{
		return názov;
	}


	/**
	 * Priradenie nového slovného opisu miestnosti. Túto metódu používa
	 * konštruktor a môže poslúžiť na zmenu slovného opisu miestnosti počas
	 * hry.
	 */
	public void priraďOpis(String novýOpis)
	{
		opis = novýOpis;
	}

	/**
	 * Táto metóda slúži na výpis slovného opisu miestnosti na obrazovku.
	 */
	public void vypíšOpis()
	{
		if (null != opis)
			Adventúra.vypíšText(opis);
	}
}
